Structs
- AddNodes
Options - AddNodes
Result - Assets
Layout - Layout of generated assets for a given network.
- Custom
Asset Install Options - Setup
Local Result - Setup
Options - Parameters for building a local devnet asset tree.
- Stage
Protocol Options - Stage
Protocol Result
Enums
Constants
Functions
- add_
nodes - Prepare filesystem assets for appending managed non-genesis nodes to a live network.
- assets_
bundle_ root - binary_
address - custom_
asset_ path - custom_
assets_ root - data_
dir - default_
assets_ root - derived_
accounts_ summary - diagnostics_
proxy_ port - diagnostics_
socket_ path - diagnostics_
ws_ endpoint - ensure_
consensus_ keys - Ensure consensus secret keys are present for all nodes.
- ensure_
network_ hook_ samples - file_
name - has_
bundle_ version - install_
assets_ bundle - install_
custom_ asset - list_
bundle_ versions - list_
custom_ asset_ names - most_
recent_ bundle_ version - network_
address - optional_
asset_ selector - parse_
protocol_ version - prepare_
genesis_ hooks - pull_
assets_ bundles - remove_
consensus_ keys - Remove consensus secret keys for the provided node IDs.
- required_
asset_ selector - rest_
endpoint - rollback_
added_ nodes - rpc_
endpoint - setup_
local - Create or refresh local assets for a devnet.
- spawn_
block_ added_ hook - spawn_
pending_ post_ genesis_ hook - sse_
endpoint - stage_
protocol - teardown
- Remove assets for the given network while preserving network hook state.