pub async fn restart_sidecars(
layout: &AssetsLayout,
state: &mut State,
rust_log: &str,
) -> Result<Vec<RunningProcess>>Expand description
Restart sidecars for all nodes, updating persisted process state.
pub async fn restart_sidecars(
layout: &AssetsLayout,
state: &mut State,
rust_log: &str,
) -> Result<Vec<RunningProcess>>Restart sidecars for all nodes, updating persisted process state.