Module process

Module process 

Structs

RunningProcess
A started process plus its handle for lifecycle tracking.
StartPlan
Start parameters derived from CLI arguments.

Enums

ProcessHandle
Handle types for started processes.

Functions

restart_sidecars
Restart sidecars for all nodes, updating persisted process state.
start
Start all nodes (and sidecars if available), updating state on success.
start_added_nodes
Start newly added nodes and track their node/sidecar processes in state.
stop
Stop all running processes tracked in state.